@@ -4,6 +4,7 @@ log = logging.getLogger("sdkit")
 LOG_FORMAT = "%(asctime)s.%(msecs)03d %(levelname)s %(threadName)s %(message)s"
 logging.basicConfig(level=logging.INFO, format=LOG_FORMAT, datefmt="%X")
 
+
 from .file_utils import load_tensor_file, save_dicts, save_images, save_tensor_file
 from .hash_utils import hash_bytes, hash_file_quick, hash_url_quick
 from .http_utils import download_file
@@ -20,6 +21,8 @@ from .latent_utils import (
     get_image_latent_and_mask,
     img_to_tensor,
     latent_samples_to_images,
+    to_tensor,
+    tensor_to_bitmap,
 )
 from .memory_utils import (
     gc,
